pypop |Build Status|
====================

A python library to compose pop songs automatically.

Installation
------------

.. code:: bash

    # Use python3.6 or above
    $ pip3 install pypop

Try Example
-----------

.. code:: bash

    $ git clone git@github.com:yuma-m/pypop.git
    $ cd pypop
    $ python3 example.py

Supported Python Versions
-------------------------

-  3.6 and above

.. |Build Status| image:: https://travis-ci.org/yuma-m/pypop.svg?branch=master
   :target: https://travis-ci.org/yuma-m/pypop
